<?php
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

 
require_once ("../data_layer/data_access_layer.php");
require_once ("class_info.php");

define ("DBNAME_MSSQL", "MSSQL");
define ("DBNAME_MYSQL", "MySQL");
define ("STATUS_SUCCESS", 1);	//This represents a success status.
define ("STATUS_FAILURE", 0);	//This represents a failure status.

define ("SERVICE_NAME_DOTNET_BS", "DOTNET_BS");
define ("SERVICE_NAME_PHP_BS", "PHP_BS");
define ("SERVICE_NAME_JAVA_BS", "JAVA_BS");
define ("SERVICE_NAME_SPRING_BS", "SPRING_BS");
define ("SERVICE_NAME_PERL_BS", "PERL_BS");
define ("SERVICE_NAME_DOTNET_OPS", "DOTNET_OPS");
define ("SERVICE_NAME_PHP_OPS", "PHP_OPS");
define ("SERVICE_NAME_JAVA_OPS", "JAVA_OPS");
define ("SERVICE_NAME_SPRING_OPS", "SPRING_OPS");
define ("SERVICE_NAME_PERL_OPS", "PERL_OPS");
define ("SERVICE_NAME_RUBY_OPS", "RUBY_OPS");
define ("SERVICE_NAME_DOTNET_OPSSEC", "DOTNET_OPSSEC");
define ("SERVICE_NAME_PHP_OPSSEC", "PHP_OPSSEC");
define ("SERVICE_NAME_JAVA_OPSSEC", "JAVA_OPSSEC");
define ("SERVICE_NAME_SPRING_OPSSEC", "SPRING_OPSSEC");
define ("SERVICE_NAME_PERL_OPSSEC", "PERL_OPSSEC");
define ("SERVICE_NAME_RUBY_OPSSEC", "RUBY_OPSSEC");
define ("CLIENT_NAME_DOTNET", "DOTNET_CLIENT");
define ("CLIENT_NAME_PHP", "PHP_CLIENT");
define ("CLIENT_NAME_RUBY", "RUBY_CLIENT");

/** 
 * Checks whether given name is a valid Business Service name 
 * @param $serviceName name of the service
 * @return STATUS_SUCCESS if valid BS Name. STATUS_FAILURE if not
 */
function isBusinessServiceDefined($serviceName)
{
	if(($serviceName == SERVICE_NAME_DOTNET_BS) ||
	   ($serviceName == SERVICE_NAME_PHP_BS) ||
	   ($serviceName == SERVICE_NAME_JAVA_BS) ||
	   ($serviceName == SERVICE_NAME_SPRING_BS) ||
	   ($serviceName == SERVICE_NAME_PERL_BS))
	{
		return STATUS_SUCCESS;
	}
	else
	{
		return STATUS_FAILURE;
	}
}

/** 
 * Checks whether given name is a valid Order Processor Service (Non-secure) name 
 * @param $serviceName name of the service
 * @return STATUS_SUCCESS if valid BS Name. STATUS_FAILURE if not
 */
function isOrderProcessorServiceDefined($serviceName)
{
	if(($serviceName == SERVICE_NAME_DOTNET_OPS) ||
	   ($serviceName == SERVICE_NAME_PHP_OPS) ||
	   ($serviceName == SERVICE_NAME_JAVA_OPS) ||
	   ($serviceName == SERVICE_NAME_SPRING_OPS) ||
	   ($serviceName == SERVICE_NAME_RUBY_OPS) ||
	   ($serviceName == SERVICE_NAME_PERL_OPS))
	{
		return STATUS_SUCCESS;
	}
	else
	{
		return STATUS_FAILURE;
	}
}

/** 
 * Checks whether given name is a valid Order Processor Service (secure) name 
 * @param $serviceName name of the service
 * @return STATUS_SUCCESS if valid BS Name. STATUS_FAILURE if not
 */
function isOrderProcessorSecDefined($serviceName)
{
	if(($serviceName == SERVICE_NAME_DOTNET_OPSSEC) ||
	   ($serviceName == SERVICE_NAME_PHP_OPSSEC) ||
	   ($serviceName == SERVICE_NAME_JAVA_OPSSEC) ||
	   ($serviceName == SERVICE_NAME_SPRING_OPSSEC) ||
	   ($serviceName == SERVICE_NAME_RUBY_OPSSEC) ||
	   ($serviceName == SERVICE_NAME_PERL_OPSSEC))
	{
		return STATUS_SUCCESS;
	}
	else
	{
		return STATUS_FAILURE;
	}
}

/** 
 * Checks whether given name is a valid client name 
 * @param $clientName name of the client
 * @return STATUS_SUCCESS if valid client Name. STATUS_FAILURE if not
 */
function isClientDefined($clientName)
{
	if(($clientName == CLIENT_NAME_DOTNET) ||
	   ($clientName == CLIENT_NAME_PHP) ||
	   ($clientName == CLIENT_NAME_RUBY))
	{
		return STATUS_SUCCESS;
	}
	else
	{
		return STATUS_FAILURE;
	}
}

/**
 * gets Service Location of given service
 * @param $serviceName service name for which we have to find config details
 * @param $db database object
 * @return if successful, ServiceLocation object filled with information. NULL otherwise
 */
function getServiceLocation($serviceName, $db)
{
	$query = "SELECT servicename, url FROM service WHERE servicename = '$serviceName'";

	$result =  $db->ExecuteQuery($query);
	if (($result) && ($db->GetSQLValue($result, 0, 0)))	//return value is having atleast one row
	{
		$config = new ServiceLocation();
		$config->ServiceName =  $serviceName;
		$config->ServiceURL = $db->GetSQLValue($result, 0, 1); //Get the url of the service
	}
	return $config;
}

/**
 * gets connection between client and BS
 * @param $client client name for which we have to find config details
 * @param $db database object
 * @return if successful, ClientToBS object filled with information. NULL otherwise
 */
function getClientToBS($client, $db)
{
	$query = "SELECT client, bs FROM clienttobs WHERE client = '$client'";

	$result =  $db->ExecuteQuery($query);
	if (($result) && ($db->GetSQLValue($result, 0, 0)))	//return value is having atleast one row
	{
		$config = new ClientToBS();
		$config->Client =  $client;
		$config->BS = $db->GetSQLValue($result, 0, 1); //Get the BS name connected to client
	}
	return $config;
}

/**
 * gets connection between BS and OPS
 * @param $BS business service name for which we have to find config details
 * @param $db database object
 * @return if successful, BSToOPS object filled with information. NULL otherwise
 */
function getBSToOPS($BS, $db)
{
	$query = "SELECT bs, ops FROM bstoops WHERE bs = '$BS'";

	$result =  $db->ExecuteQuery($query);
	if (($result) && ($db->GetSQLValue($result, 0, 0)))		//return value is having atleast one row
	{
		$config = new BSToOPS();
		$config->BS =  $BS;
		$config->OPS = $db->GetSQLValue($result, 0, 1); //Get the OPS name connected to BS
	}
	return $config;
}

/**
 * gets DBConfig of given database
 * @param $DBName database name for which we have to find config details
 * @param $db database object
 * @return if successful, DBConfig object filled with information. NULL otherwise
 */
function getDBConfig($DBName, $db)
{
	$query = "SELECT dbname, hostname, port FROM dbconfig WHERE dbname = '$DBName'";

	$result =  $db->ExecuteQuery($query);
	if (($result) && ($db->GetSQLValue($result, 0, 0))) 		//return value is having atleast one row
	{
		$config = new DBConfig();
		$config->DBName =  $DBName;
		$config->DBHostName = $db->GetSQLValue($result, 0, 1); //Get the host name.
		$config->DBPort = $db->GetSQLValue($result, 0, 2); 	//Get the port
	}
	return $config;
}

/**
 * gets DBConfig of active database
 * @param $db database object
 * @return if successful, DBConfig object filled with information. NULL otherwise
 */
function getActiveDBConfig($db)
{
	$query = "SELECT dbname, hostname, port FROM dbconfig WHERE active = 'Y'";

	$result =  $db->ExecuteQuery($query);
	if (($result) && ($db->GetSQLValue($result, 0, 0)))		//return value is having atleast one row
	{
		$config = new DBConfig();
		$config->DBName =  $db->GetSQLValue($result, 0, 0);	//Get the db name.
		$config->DBHostName = $db->GetSQLValue($result, 0, 1); //Get the host name.
		$config->DBPort = $db->GetSQLValue($result, 0, 2); 	//Get the port
	}
	return $config;
}

?>
