<?php 
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * This class encapsulates information regarding the establishment
 * of database connection.
 */
class ConnectionInfo
{
	public $server; 	//The database server (eg: 127.0.0.1:1433)
	public $user;		//User name 
	public $password;	//Password
	public $database;	//Database name
	public $type;		//RDBMS type (eg: mssql, mysql)
}

/** 
 * This class gives an abstract interfaces to generic database
 */
abstract class Database
{
	/**
	 * This method establishes a connection to the database. 
	 * @return boolean, upon successfull execution true is returned. 
	 * Otherwise false will be returned. 
	 */
	abstract public function ConnectToDatabase();

	/**
	 * This method close the connection that is established to the
	 * database.
	 */
	abstract public function CloseDatabase();

	/**
	 * This method executes a query that it receives.
	 * @param query the query to execute
	 * @return non-NULL upon success and NULL otherwise.
	 */
	abstract public function ExecuteQuery($query);

	/**
	 * This method returns the a value from a sql result set (a tuple
	 * returned after execution of ExecuteQuery method.
	 * @param result, the result obtained from ExecuteQuery method.
	 * @param raw, the raw number
	 * @param column, the column number
	 * @return the value at (raw, column) of the tuple.
	 */
	abstract public function GetSQLValue($result, $raw, $column);

	/**
	 * Gets the ID of the last inserted record. returns -1 if error
	 */
	abstract public function GetInsertID();

	/**
	 * Begin a transaction. return status will be not null if success
	 */
	abstract public function BeginTransaction();

	/**
	 * Commit a transaction. return status will be not null if success
	 */
	abstract public function CommitTransaction();

	/**
	 * Rollback a transaction.return status will be not null if success
	 */
	abstract public function RollbackTransaction();
}

?>
